searchData={"items":[{"type":"module","title":"Turboprop","doc":"","ref":"Turboprop.html"},{"type":"module","title":"Tools - Turboprop","doc":"Turboprop consists of multiple tools, each with their own purpose in building your component library.","ref":"Turboprop.html#module-tools"},{"type":"module","title":"Turboprop Hooks - Turboprop","doc":"Turboprop Hooks allow adding a ton of accessibility features to your components by simply adding a hook and a few data attributes to them.  \nThis includes:\n\n- Keyboard interactions\n- Focus management\n- ARIA attributes\n\nYou can either install and use them through the hex.pm dependency and some helpers we offer to add the relevant attributes to a component,\nor install them directly through npm and adding the attributes yourself.  \n\nAs an example, this renders a fully accessible dropdown menu:\n\n```heex\n \n   \n    Menu\n   \n   \n     \n       \n        Link\n       \n       Anchor \n     \n   \n \n```","ref":"Turboprop.html#module-turboprop-hooks"},{"type":"module","title":"Turboprop Merge - Turboprop","doc":"Turboprop Merge allows you to easily merge a list of Tailwind Classes to avoid style conflicts.\n\nImagine this component:\n\n```elixir\nattr :class, :string, doc: \"Class override\"\ndef button(assigns) do\n  ~H\"\"\"\n   Click me! \n  \"\"\"\nend\n```\n\nAnd imagine wanting to make the text a little bigger as a one-off. You've already added a `@class` attribute, but rendering the component\nwith `class=\"text-lg\"` will lead to an HTML output of `\"bg-black px-3 py-1.5 text-sm text-lg\"`, with two competing font size classes.\n\nNow, replace the `class` attribute with `class={merge([\"bg-black px-3 py-1.5 text-sm\", @class])}` and you will magically get\n`\"bg-black px-3 py-1.5 text-lg\"`.","ref":"Turboprop.html#module-turboprop-merge"},{"type":"module","title":"Turboprop Variants - Turboprop","doc":"Turboprop Variants is a variant API for TailwindCSS and Phoenix.\n\n```elixir\ndef button() do\n  %{\n    base: \"inline-flex items-center justify-center whitespace-nowrap rounded-md text-sm font-medium transition-colors focus-visible:outline-none focus-visible:ring-1 focus-visible:ring-ring disabled:pointer-events-none disabled:opacity-50\",\n    variants: %{\n      variant: %{\n        default: \"bg-primary text-primary-foreground shadow hover:bg-primary/90\",\n        destructive: \"bg-destructive text-destructive-foreground shadow-sm hover:bg-destructive/90\",\n        outline: \"border border-input bg-background shadow-sm hover:bg-accent hover:text-accent-foreground\",\n        secondary: \"bg-secondary text-secondary-foreground shadow-sm hover:bg-secondary/80\",\n        ghost: \"hover:bg-accent hover:text-accent-foreground\",\n        link: \"text-primary underline-offset-4 hover:underline\"\n      },\n      size: %{\n        default: \"h-9 px-4 py-2\",\n        sm: \"h-8 rounded-md px-3 text-xs\",\n        lg: \"h-10 rounded-md px-8\",\n        icon: \"h-9 w-9\"\n      }\n    },\n    default_variants: [\n      variant: \"default\",\n      size: \"default\"\n    ]\n  }\nend\n\ndef render(assigns) do\n  ~H\"\"\"\n   A large, outlined button \n  \"\"\"\nend\n```\n\nIt supports variants, boolean variants, default variants, compound variants, slots, compound slots and more.","ref":"Turboprop.html#module-turboprop-variants"},{"type":"module","title":"Turboprop.Hooks","doc":"Turboprop Hooks offer an easy way to build accessible components.  \n\nYou can easily add features like keyboard interaction, focus management and ARIA attributes to your component.  \nTurboprop Hooks are built around the state machines of [Zag](https://zagjs.com) and offer the same rules as them. You will find a link to\neach state machine's documentation in the hook's module.","ref":"Turboprop.Hooks.html"},{"type":"module","title":"Installation - Turboprop.Hooks","doc":"","ref":"Turboprop.Hooks.html#module-installation"},{"type":"module","title":"With mix - Turboprop.Hooks","doc":"If you use the esbuild setup Phoenix ships with by default, the hooks will automatically be available to your assets after adding\nTurboprop to your `mix.exs`. You then only need to add the hooks to your LiveView configuration.","ref":"Turboprop.Hooks.html#module-with-mix"},{"type":"module","title":"With npm - Turboprop.Hooks","doc":"The hooks are also available packaged as an npm package, [`@leuchtturm/turboprop`](https://npmjs.com/package/@leuchtturm/turboprop). Add \nit to your assets by running `npm i --save-exact @leuchtturm/turboprop` or the equivalent for the package manager you are using.","ref":"Turboprop.Hooks.html#module-with-npm"},{"type":"module","title":"Loading the hooks - Turboprop.Hooks","doc":"To reduce bundle size, it's recommended to only add the hooks actually used. For example, if only the `PinInput` hook is used:\n\n```javascript\nimport { PinInput } from \"@leuchtturm/turboprop\";\n\nlet liveSocket = new LiveSocket(\"/live\", Socket, {\n  hooks: {\n    PinInput\n  },\n});\n```\n\nFor convenience, Turboprop also allows importing and adding all hooks at once:\n\n```javascript\nimport { Hooks } from \"@leuchtturm/turboprop\";\n\nlet liveSocket = new LiveSocket(\"/live\", Socket, {\n  hooks: {\n    ...Hooks\n  },\n});\n```\n\nThat's it!","ref":"Turboprop.Hooks.html#module-loading-the-hooks"},{"type":"module","title":"Anatomy - Turboprop.Hooks","doc":"Each hook comes with a wrapper that adds the `phx-hook` directive and a bunch of `data` attributes that specify which role each element\nhas. Revisiting the dropdown menu example from the [Turboprop](`m:Turboprop`) documentation, the expanded elements look like this:\n\n```html\n \n   \n    Menu\n   \n   \n     \n       \n        Link\n       \n       \n        Anchor\n       \n     \n   \n \n```\nFor the `Menu` hook, the required parts are `trigger`, `positioner`, `content`, and `item`. In addition to that, it can also be configured\nwith optional parts like `separator` and `group`. Each hook's module will list both required and optional fields and how they relate to\neach other with nesting.  \nMost hooks only need the `data-part` attributes set, but some also have callbacks to the server where an event is required. Check the\ndocumentation for each hook.","ref":"Turboprop.Hooks.html#module-anatomy"},{"type":"function","title":"Turboprop.Hooks.id/0","doc":"","ref":"Turboprop.Hooks.html#id/0"},{"type":"module","title":"Turboprop.Hooks.Dialog","doc":"A dialog component, also known as Modal.","ref":"Turboprop.Hooks.Dialog.html"},{"type":"module","title":"Required elements - Turboprop.Hooks.Dialog","doc":"- `dialog`: Wrapper element that initialises the hook and sets configuration.\n- `dialog_trigger`: Trigger that opens the dialog.\n- `dialog_positioner`: Controls the menu's position in the viewport.\n- `dialog_content`: Contains the dialog content.","ref":"Turboprop.Hooks.Dialog.html#module-required-elements"},{"type":"module","title":"Optional elements - Turboprop.Hooks.Dialog","doc":"- `dialog_backdrop`: Backdrop to cover the rest of the viewport.\n- `dialog_title`: Title of the dialog.\n- `dialog_description`: Description of the dialog.\n- `dialog_close_trigger`: Trigger to close the dialog.","ref":"Turboprop.Hooks.Dialog.html#module-optional-elements"},{"type":"module","title":"Options - Turboprop.Hooks.Dialog","doc":"Options are set on the outer wrapper element through data attributes.  \nFor boolean attributes, adding the attribute with either an empty value or `\"true\"` is considered truthy, every other value falsy.\n\n- `data-prevent-scroll`: Prevent scrolling of the body behind the dialog. Defaults to `true`.\n- `data-close-on-interact-outside`: Close the dialog when interacting with an element outside of it. Defaults to `true`.\n- `data-close-on-escape`: Close the dialog when the Escape key is pressed. Defaults to `true`.","ref":"Turboprop.Hooks.Dialog.html#module-options"},{"type":"module","title":"Events - Turboprop.Hooks.Dialog","doc":"","ref":"Turboprop.Hooks.Dialog.html#module-events"},{"type":"module","title":"From the client - Turboprop.Hooks.Dialog","doc":"If set, the client will push the following events to the server:\n\n- `data-on-open-change`: Emitted when the open state of the dialog changes.","ref":"Turboprop.Hooks.Dialog.html#module-from-the-client"},{"type":"module","title":"Example - Turboprop.Hooks.Dialog","doc":"```heex\n \n   \n    Open dialog\n   \n    \n   \n     \n       Dialog \n       Welcome to Guillotine! \n       \n         \n          Close\n         \n       \n     \n   \n \n```","ref":"Turboprop.Hooks.Dialog.html#module-example"},{"type":"function","title":"Turboprop.Hooks.Dialog.dialog/0","doc":"Wrapper element to initialise the hook.","ref":"Turboprop.Hooks.Dialog.html#dialog/0"},{"type":"function","title":"Turboprop.Hooks.Dialog.dialog_backdrop/0","doc":"Backdrop element.\n\nNeeds to be positioned as child of `dialog/0`.","ref":"Turboprop.Hooks.Dialog.html#dialog_backdrop/0"},{"type":"function","title":"Turboprop.Hooks.Dialog.dialog_close_trigger/0","doc":"Trigger to close the dialog.\n\nNeeds to be positioned as child of `dialog/0`.","ref":"Turboprop.Hooks.Dialog.html#dialog_close_trigger/0"},{"type":"function","title":"Turboprop.Hooks.Dialog.dialog_content/0","doc":"Content of the dialog.\n\nNeeds to be positioned as child of `dialog_positioner/0`.","ref":"Turboprop.Hooks.Dialog.html#dialog_content/0"},{"type":"function","title":"Turboprop.Hooks.Dialog.dialog_description/0","doc":"Description of the dialog.\n\nNeeds to be positioned as child of `dialog_content/0`.","ref":"Turboprop.Hooks.Dialog.html#dialog_description/0"},{"type":"function","title":"Turboprop.Hooks.Dialog.dialog_positioner/0","doc":"Element to position a dialog in the viewport.\n\nNeeds to be positioned as child of `dialog/0`.","ref":"Turboprop.Hooks.Dialog.html#dialog_positioner/0"},{"type":"function","title":"Turboprop.Hooks.Dialog.dialog_title/0","doc":"Title of the dialog.\n\nNeeds to be positioned as child of `dialog_content/0`.","ref":"Turboprop.Hooks.Dialog.html#dialog_title/0"},{"type":"function","title":"Turboprop.Hooks.Dialog.dialog_trigger/0","doc":"Trigger to open the dialog.\n\nNeeds to be positioned as child of `dialog/0`.","ref":"Turboprop.Hooks.Dialog.html#dialog_trigger/0"},{"type":"module","title":"Turboprop.Hooks.Menu","doc":"Provides a robust, accessible dropdown and context menu system. This module serves as a wrapper around\n[Zag's Menu state machine](https://github.com/chakra-ui/zag/tree/main/packages/machines/menu), designed for displaying a list of actions \nor options to the user within a web application.","ref":"Turboprop.Hooks.Menu.html"},{"type":"module","title":"Required Components: - Turboprop.Hooks.Menu","doc":"- `menu`: The main container for the menu.\n- `menu_trigger`: Activates the dropdown or context menu.\n- `menu_positioner`: Controls the menu's position in the viewport.\n- `menu_content`: Contains the clickable menu items.\n- `menu_item`: Represents an individual action or option within the menu.","ref":"Turboprop.Hooks.Menu.html#module-required-components"},{"type":"module","title":"Optional Components: - Turboprop.Hooks.Menu","doc":"- `menu_item_group`: Groups related items within the menu.\n- `menu_item_group_label`: Provides a label for item groups, enhancing accessibility.\n- `menu_separator`: Visually separates items or groups within the menu.","ref":"Turboprop.Hooks.Menu.html#module-optional-components"},{"type":"module","title":"Example - Turboprop.Hooks.Menu","doc":"```heex\n \n   \n    Menu\n   \n   \n     \n      <.link navigate=\"/dashboard\" class=\"block px-4 py-2 outline-0 data-[highlighted]:bg-gray-100\" {menu_item()}>\n        Dashboard\n      </.link>\n       \n       Account \n       \n        <.link navigate=\"/signup\" class=\"block px-4 py-2 outline-0 data-[highlighted]:bg-gray-100\" {menu_item()}>\n          Sign up\n        </.link>\n        <.link navigate=\"/login\" class=\"block px-4 py-2 outline-0 data-[highlighted]:bg-gray-100\" {menu_item()}>\n          Login\n        </.link>\n       \n     \n   \n \n```","ref":"Turboprop.Hooks.Menu.html#module-example"},{"type":"function","title":"Turboprop.Hooks.Menu.menu/0","doc":"Wrapper element for menus.","ref":"Turboprop.Hooks.Menu.html#menu/0"},{"type":"function","title":"Required attributes - Turboprop.Hooks.Menu.menu/0","doc":"- `id` - Will be auto-generated if not set.","ref":"Turboprop.Hooks.Menu.html#menu/0-required-attributes"},{"type":"function","title":"Turboprop.Hooks.Menu.menu_content/0","doc":"Wrapper around menu items.\n\nNeeds to be positioned as direct child of `menu_positioner/0`.","ref":"Turboprop.Hooks.Menu.html#menu_content/0"},{"type":"function","title":"Turboprop.Hooks.Menu.menu_item/0","doc":"Menu item.","ref":"Turboprop.Hooks.Menu.html#menu_item/0"},{"type":"function","title":"Required attributes - Turboprop.Hooks.Menu.menu_item/0","doc":"- `id` - Will be auto-generated if not set.","ref":"Turboprop.Hooks.Menu.html#menu_item/0-required-attributes"},{"type":"function","title":"Styling - Turboprop.Hooks.Menu.menu_item/0","doc":"When a menu item is highlighted, it will receive a `data-highlighted` attribute which can be used to style the item. If using Tailwind,\nthis can be achieved by adding `data-[highlighted]:bg-gray-100` to the class list.","ref":"Turboprop.Hooks.Menu.html#menu_item/0-styling"},{"type":"function","title":"Turboprop.Hooks.Menu.menu_item_group/0","doc":"Element to group multiple menu items together.","ref":"Turboprop.Hooks.Menu.html#menu_item_group/0"},{"type":"function","title":"Required attributes - Turboprop.Hooks.Menu.menu_item_group/0","doc":"- `id` - Will be auto-generated if not set.\n- `name` - If adding a label through `menu_item_group_label/0`, the group needs to have a name set.","ref":"Turboprop.Hooks.Menu.html#menu_item_group/0-required-attributes"},{"type":"function","title":"Turboprop.Hooks.Menu.menu_item_group_label/0","doc":"Label for a menu group.","ref":"Turboprop.Hooks.Menu.html#menu_item_group_label/0"},{"type":"function","title":"Required attributes - Turboprop.Hooks.Menu.menu_item_group_label/0","doc":"- `data-for` - The `menu_item_group/0`'s `name`.","ref":"Turboprop.Hooks.Menu.html#menu_item_group_label/0-required-attributes"},{"type":"function","title":"Turboprop.Hooks.Menu.menu_positioner/0","doc":"Element to position a menu in the viewport.\n\nNeeds to be positioned as direct child of `menu/0`.","ref":"Turboprop.Hooks.Menu.html#menu_positioner/0"},{"type":"function","title":"Turboprop.Hooks.Menu.menu_separator/0","doc":"Element to separate menu items.\n\nNeeds to be positioned as direct child of either `menu_content/0` or `menu_item_group/0`.","ref":"Turboprop.Hooks.Menu.html#menu_separator/0"},{"type":"function","title":"Turboprop.Hooks.Menu.menu_trigger/0","doc":"Button to open a menu.\n\nNeeds to be positioned as direct child of `menu/0`.","ref":"Turboprop.Hooks.Menu.html#menu_trigger/0"},{"type":"module","title":"Turboprop.Hooks.PinInput","doc":"Input for PINs and OTPs.\n\nConsists of multiple inputs, each allowing one character at a time. When the digit or letter is entered, focus transfers to the next \ninput in the sequence, until every input is filled.","ref":"Turboprop.Hooks.PinInput.html"},{"type":"module","title":"Required elements - Turboprop.Hooks.PinInput","doc":"- `pin_input`: Wrapper element that initialises the hook and sets configuration.\n- `pin_input_root`: Wrapper around the actual input fields.\n- `pin_input_input`: Input elements, one for each character.","ref":"Turboprop.Hooks.PinInput.html#module-required-elements"},{"type":"module","title":"Optional elements - Turboprop.Hooks.PinInput","doc":"- `pin_input_label`: Label for the input.","ref":"Turboprop.Hooks.PinInput.html#module-optional-elements"},{"type":"module","title":"Options - Turboprop.Hooks.PinInput","doc":"Options are set on the outer wrapper element through data attributes.  \nFor boolean attributes, adding the attribute with either an empty value or `\"true\"` is considered truthy, every other value falsy.\n\n- `data-type`: The type of the input. Defines which characters are allowed. Has to be one of `alphanumeric`, `numeric` or `alphabetic`.\n- `data-otp`: Add when the input is a One-Time Password to correctly set the `autocomplete` tag.\n- `data-blur-on-complete`: Blur the last input when the user completes the pin input.\n- `data-placeholder`: The placeholder to show in each input field.\n- `data-dir`: Set to `rtl` if the pin should be entered right-to-left.","ref":"Turboprop.Hooks.PinInput.html#module-options"},{"type":"module","title":"Events - Turboprop.Hooks.PinInput","doc":"","ref":"Turboprop.Hooks.PinInput.html#module-events"},{"type":"module","title":"From the client - Turboprop.Hooks.PinInput","doc":"If set, the client will push the following events to the server:\n\n- `data-on-change`: Emitted when any of the inputs change.\n- `data-on-complete`: Emitted when all inputs have been filled.\n- `data-on-invalid`: Emitted when the entire input is invalid.","ref":"Turboprop.Hooks.PinInput.html#module-from-the-client"},{"type":"module","title":"From the server - Turboprop.Hooks.PinInput","doc":"The following events can be sent to the component through `push_event/3`.\n\n- `clear`: Clears the input. Accepts no parameters.","ref":"Turboprop.Hooks.PinInput.html#module-from-the-server"},{"type":"module","title":"Example - Turboprop.Hooks.PinInput","doc":"```elixir\ndef render(assigns) do\n  ~H\"\"\"\n   \n     \n       OTP \n       \n         \n         \n         \n       \n     \n   \n  \"\"\"\nend\n\n@impl true\ndef handle_event(\"submit\", %{\"value\" => value}, socket) do\n  # Do something with value...\n  {:noreply, socket}\n  \nend\n```","ref":"Turboprop.Hooks.PinInput.html#module-example"},{"type":"function","title":"Turboprop.Hooks.PinInput.pin_input/0","doc":"Wrapper element to initialise the hook.","ref":"Turboprop.Hooks.PinInput.html#pin_input/0"},{"type":"function","title":"Turboprop.Hooks.PinInput.pin_input_input/0","doc":"Input element.\n\nSince the pin input allows one character per input, this element needs to be added multiple times.","ref":"Turboprop.Hooks.PinInput.html#pin_input_input/0"},{"type":"function","title":"Required attributes - Turboprop.Hooks.PinInput.pin_input_input/0","doc":"- `data-index`: Increasing index for each input. Needs to be an integer *and* start at `0`.","ref":"Turboprop.Hooks.PinInput.html#pin_input_input/0-required-attributes"},{"type":"function","title":"Turboprop.Hooks.PinInput.pin_input_label/0","doc":"Label for the input.","ref":"Turboprop.Hooks.PinInput.html#pin_input_label/0"},{"type":"function","title":"Turboprop.Hooks.PinInput.pin_input_root/0","doc":"Wrapper around the input.","ref":"Turboprop.Hooks.PinInput.html#pin_input_root/0"},{"type":"module","title":"Turboprop.Merge","doc":"Turboprop Merge adds efficient class joining and merging of TailwindCSS classes to Elixir.\n\nTailwindCSS class names are composable and allow specifying an infinite amount of different styles. Most components allow overriding class\nnames, like as passing `class` attribute that then gets merged with the existing styles. This can result in class lists such as\n`text-white bg-red-500 bg-blue-300` where `text-white bg-red-500` is the preset style, and `bg-blue-300` is the override for that one\nspecific button that needs to look slightly different.  \nStyles based on class are applied according to the order _they are defined at in the stylesheet_. In this example, because TailwindCSS\norders color definitions alphabetically, the override does not work. `blue` is defined before `red`, so the `bg-red-500` class takes\nprecedence since it was defined later.  \n\nIn order to still allow overriding styles, Turboprop Merge traverses the entire class list, creates a list of all classes and which\nconflicting groups of styles exist in them and gives precedence to the ones that were defined last _in the class list_, which, unlike the\nstylesheet, is in control of the user.","ref":"Turboprop.Merge.html"},{"type":"module","title":"Example - Turboprop.Merge","doc":"```elixir\niex> merge(\"text-white bg-red-500 bg-blue-300\")\n\"text-white bg-blue-300\"\n\niex> merge([\"px-2 py-1 bg-red hover:bg-dark-red\", \"p-3 bg-[#B91C1C]\"])\n\"hover:bg-dark-red p-3 bg-[#B91C1C]\"\n```","ref":"Turboprop.Merge.html#module-example"},{"type":"function","title":"Turboprop.Merge.join/1","doc":"Joins a list of classes.","ref":"Turboprop.Merge.html#join/1"},{"type":"function","title":"Turboprop.Merge.merge/2","doc":"Joins and merges a list of classes.\n\nPasses the input to `join/1` before merging.","ref":"Turboprop.Merge.html#merge/2"},{"type":"module","title":"Turboprop.Variants","doc":"Turboprop Variants adds a feature-rich variant API for TailwindCSS to Elixir.\n\nVariants allow you to define all possible styles and options for a component, even one that spans multiple HTML elements, in one place,\nand then apply them based on your assigns.","ref":"Turboprop.Variants.html"},{"type":"module","title":"Example - Turboprop.Variants","doc":"```elixir\ndef button() do\n  %{\n    base: \"inline-flex items-center justify-center whitespace-nowrap rounded-md text-sm font-medium transition-colors focus-visible:outline-none focus-visible:ring-1 focus-visible:ring-ring disabled:pointer-events-none disabled:opacity-50\",\n    variants: %{\n      variant: %{\n        default: \"bg-primary text-primary-foreground shadow hover:bg-primary/90\",\n        destructive: \"bg-destructive text-destructive-foreground shadow-sm hover:bg-destructive/90\",\n        outline: \"border border-input bg-background shadow-sm hover:bg-accent hover:text-accent-foreground\",\n        secondary: \"bg-secondary text-secondary-foreground shadow-sm hover:bg-secondary/80\",\n        ghost: \"hover:bg-accent hover:text-accent-foreground\",\n        link: \"text-primary underline-offset-4 hover:underline\"\n      },\n      size: %{\n        default: \"h-9 px-4 py-2\",\n        sm: \"h-8 rounded-md px-3 text-xs\",\n        lg: \"h-10 rounded-md px-8\",\n        icon: \"h-9 w-9\"\n      }\n    },\n    default_variants: [\n      variant: \"default\",\n      size: \"default\"\n    ]\n  }\nend\n```","ref":"Turboprop.Variants.html#module-example"},{"type":"module","title":"Features - Turboprop.Variants","doc":"Turboprop Variants comes with a ton of features to manage your variants.","ref":"Turboprop.Variants.html#module-features"},{"type":"module","title":"Variants - Turboprop.Variants","doc":"You can add variants and their options inside the `variants` map. \n\n```elixir\niex> alert = %{\n...>   variants: %{\n...>     variant: %{\n...>       default: \"bg-background text-foreground\",\n...>       destructive: \"border-destructive/50 text-destructive dark:border-destructive [&>svg]:text-destructive\",\n...>     }\n...>   }\n...> }\niex> variant(alert, variant: \"destructive\")\n\"border-destructive/50 text-destructive dark:border-destructive [&>svg]:text-destructive\"\n```\n\n#### Multiple variants\n\nEach component can have any number of variants.\n\n```elixir\niex> button = %{\n...>   variants: %{\n...>     variant: %{\n...>       default: \"bg-primary text-primary-foreground shadow hover:bg-primary/90\",\n...>       destructive: \"bg-destructive text-destructive-foreground shadow-sm hover:bg-destructive/90\",\n...>       outline: \"border border-input bg-background shadow-sm hover:bg-accent hover:text-accent-foreground\",\n...>       secondary: \"bg-secondary text-secondary-foreground shadow-sm hover:bg-secondary/80\",\n...>       ghost: \"hover:bg-accent hover:text-accent-foreground\",\n...>       link: \"text-primary underline-offset-4 hover:underline\",\n...>     },\n...>     size: %{\n...>       default: \"h-9 px-4 py-2\",\n...>       sm: \"h-8 rounded-md px-3 text-xs\",\n...>       lg: \"h-10 rounded-md px-8\",\n...>       icon: \"h-9 w-9\",\n...>     },\n...>   },\n...> }\niex> variant(button, variant: \"destructive\", size: \"sm\")\n\"bg-destructive text-destructive-foreground shadow-sm hover:bg-destructive/90 h-8 rounded-md px-3 text-xs\"\n```\n\n#### Boolean variants\n\nSome components benefit from having boolean variants, such as `disabled`.  \n\nPassing only one of `true` and `false` as options is allowed. By default, if the variant is not passed as a keyword and if it exists, the\n`false` value is applied.\n\n```elixir\niex> button = %{\n...>   variants: %{\n...>     variant: %{\n...>       default: \"bg-primary text-primary-foreground shadow hover:bg-primary/90\",\n...>       destructive: \"bg-destructive text-destructive-foreground shadow-sm hover:bg-destructive/90\",\n...>     },\n...>     disabled: %{\n...>       true: \"opacity-50 bg-gray-500 hover:bg-gray-500 pointer-events-none\"\n...>     },\n...>   },\n...> }\niex> variant(button, variant: \"default\")\n\"bg-primary text-primary-foreground shadow hover:bg-primary/90\"\niex> variant(button, variant: \"destructive\", disabled: true)\n\"text-destructive-foreground shadow-sm opacity-50 bg-gray-500 hover:bg-gray-500 pointer-events-none\"\n```\n\n#### Default variants\n\nDefault variants can easily be set so they do not need to be passed every time.\n\n> #### Default variants {: .info}\n>\n> Please note that the `default_variants` key expects a keyword list, not a map.\n\n```elixir\niex> button = %{\n...>   variants: %{\n...>     variant: %{\n...>       default: \"bg-primary text-primary-foreground shadow hover:bg-primary/90\",\n...>       destructive: \"bg-destructive text-destructive-foreground shadow-sm hover:bg-destructive/90\",\n...>       outline: \"border border-input bg-background shadow-sm hover:bg-accent hover:text-accent-foreground\",\n...>       secondary: \"bg-secondary text-secondary-foreground shadow-sm hover:bg-secondary/80\",\n...>       ghost: \"hover:bg-accent hover:text-accent-foreground\",\n...>       link: \"text-primary underline-offset-4 hover:underline\",\n...>     },\n...>     size: %{\n...>       default: \"h-9 px-4 py-2\",\n...>       sm: \"h-8 rounded-md px-3 text-xs\",\n...>       lg: \"h-10 rounded-md px-8\",\n...>       icon: \"h-9 w-9\",\n...>     },\n...>   },\n...>   default_variants: [\n...>     # Both strings and atoms are fine!\n...>     variant: \"default\",\n...>     size: :default\n...>   ]\n...> }\niex> variant(button)\n\"bg-primary text-primary-foreground shadow hover:bg-primary/90 h-9 px-4 py-2\"\n```\n\n#### Compound variants\n\nTurboprop Variants supports variants that depend on other variants.\n\n> #### Compound variants {: .info}\n>\n> Please note that the `compound_variants` key expects a keyword list, not a map.\n\n```elixir\niex> button = %{\n...>   variants: %{\n...>     variant: %{\n...>       default: \"bg-primary text-primary-foreground shadow hover:bg-primary/90\",\n...>       destructive: \"bg-destructive text-destructive-foreground shadow-sm hover:bg-destructive/90\",\n...>     },\n...>     disabled: %{\n...>       true: \"opacity-50 bg-gray-500 pointer-events-none\"\n...>     },\n...>   },\n...>   compound_variants: [\n...>     %{\n...>       variant: \"destructive\",\n...>       disabled: false,\n...>       class: \"focus:ring-1\"\n...>     }\n...>   ]\n...> }\niex> variant(button, variant: \"destructive\", disabled: false)\n\"bg-destructive text-destructive-foreground shadow-sm hover:bg-destructive/90 focus:ring-1\"\n```\n\nThe variants also accept arrays, in which case the compound variant will be applied when any of the values match.","ref":"Turboprop.Variants.html#module-variants"},{"type":"module","title":"Slots - Turboprop.Variants","doc":"Slots allow spreading a component's variants over multiple elements.\n\nWhen no `slot` option is provided, the `base` one is implied.  \nTo be consistent with when not using slots, the `base` slot can also be defined _outside_ the `slots` map.\n\n```elixir\niex> card = %{\n...>   # Can also go here:\n...>   # base: \"md:flex bg-slate-100 rounded-xl p-8 md:p-0 dark:bg-gray-900\",\n...>   slots: %{\n...>     base: \"md:flex bg-slate-100 rounded-xl p-8 md:p-0 dark:bg-gray-900\",\n...>     avatar: \"w-24 h-24 md:w-48 md:h-auto md:rounded-none rounded-full mx-auto drop-shadow-lg\",\n...>     wrapper: \"flex-1 pt-6 md:p-8 text-center md:text-left space-y-4\",\n...>     description: \"text-md font-medium\",\n...>   }\n...> }\niex> variant(card)\n\"md:flex bg-slate-100 rounded-xl p-8 md:p-0 dark:bg-gray-900\"\niex> variant(card, slot: :wrapper)\n\"flex-1 pt-6 md:p-8 text-center md:text-left space-y-4\"\n```\n\n#### Slots with variants\n\nSlots seamlessly work together with variants.\n\n```elixir\niex> card = %{\n...>   slots: %{\n...>     base: \"md:flex rounded-xl p-8 md:p-0\",\n...>     avatar: \"md:h-auto md:rounded-none rounded-full mx-auto drop-shadow-lg\",\n...>   },\n...>   variants: %{\n...>     color: %{\n...>       gray: %{\n...>         base: \"bg-slate-100 dark:bg-gray-900\"\n...>       },\n...>       red: %{\n...>         base: \"bg-red-100 dark:bg-red-900\"\n...>       }\n...>     },\n...>     size: %{\n...>       sm: %{\n...>         avatar: \"w-24 h-24\"\n...>       },\n...>       lg: %{\n...>         avatar: \"w-48 h-48\"\n...>       }\n...>     }\n...>   }\n...> }\niex> variant(card, color: \"gray\")\n\"md:flex rounded-xl p-8 md:p-0 bg-slate-100 dark:bg-gray-900\"\niex> variant(card, color: \"red\")\n\"md:flex rounded-xl p-8 md:p-0 bg-red-100 dark:bg-red-900\"\niex> variant(card, slot: :avatar, size: \"lg\")\n\"md:h-auto md:rounded-none rounded-full mx-auto drop-shadow-lg w-48 h-48\"\n```\n\nCompound variants can be similarly used with slots.\n\n#### Compound slots\n\nLike compound variants, Turboprop Variants also supports adding clases depending on which variants are applied.  \nThis is the \"Everything everywhere all at once\" usage.\n\n```elixir\niex> pagination = %{\n...>   slots: %{\n...>     base: \"flex flex-wrap relative gap-1 max-w-fit\",\n...>     item: \"data-[active='true']:bg-blue-500 data-[active='true']:text-white\",\n...>     prev: \"\",\n...>     next: \"\"\n...>   },\n...>   variants: %{\n...>     size: %{\n...>       xs: %{},\n...>       sm: %{},\n...>       md: %{}\n...>     }\n...>   },\n...>   default_variants: [\n...>     size: \"md\"\n...>   ],\n...>   compound_slots: [\n...>     %{\n...>       slots: [:item, :prev, :next],\n...>       class: [\n...>         \"flex\",\n...>         \"flex-wrap\",\n...>         \"truncate\",\n...>         \"box-border\",\n...>         \"outline-none\",\n...>         \"items-center\",\n...>         \"justify-center\",\n...>         \"bg-neutral-100\",\n...>         \"hover:bg-neutral-200\",\n...>         \"active:bg-neutral-300\",\n...>         \"text-neutral-500\"\n...>       ]\n...>     },\n...>     %{\n...>       slots: [:item, :prev, :next],\n...>       size: \"xs\",\n...>       class: \"w-7 h-7 text-xs\"\n...>     },\n...>     %{\n...>       slots: [:item, :prev, :next],\n...>       size: \"sm\",\n...>       class: \"w-8 h-8 text-sm\"\n...>     },\n...>     %{\n...>       slots: [:item, :prev, :next],\n...>       size: \"md\",\n...>       class: \"w-9 h-9 text-base\"\n...>     }\n...>   ]\n...> }\niex> variant(pagination)\n\"flex flex-wrap relative gap-1 max-w-fit\"\niex> variant(pagination, slot: :item)\n\"data-[active='true']:bg-blue-500 data-[active='true']:text-white flex flex-wrap truncate box-border outline-none items-center justify-center bg-neutral-100 hover:bg-neutral-200 active:bg-neutral-300 text-neutral-500 w-9 h-9 text-base\"\niex> variant(pagination, slot: :prev, size: \"xs\")\n\"flex flex-wrap truncate box-border outline-none items-center justify-center bg-neutral-100 hover:bg-neutral-200 active:bg-neutral-300 text-neutral-500 w-7 h-7 text-xs\"\n```","ref":"Turboprop.Variants.html#module-slots"},{"type":"module","title":"Overriding class names - Turboprop.Variants","doc":"For when that one special element is needed, class overrides can also be passed:\n\n\n```elixir\niex> alert = %{\n...>   variants: %{\n...>     variant: %{\n...>       default: \"bg-background text-foreground\",\n...>       destructive: \"border-destructive/50 text-destructive dark:border-destructive [&>svg]:text-destructive\",\n...>     }\n...>   }\n...> }\niex> variant(alert, variant: \"default\", class: \"bg-yellow-500\")\n\"text-foreground bg-yellow-500\"\n```","ref":"Turboprop.Variants.html#module-overriding-class-names"},{"type":"module","title":"Options - Turboprop.Variants","doc":"`variant/2` takes two parameters: The component definition and the options.\n\nOptions are optionally the slot, which always has to be an atom, and a list of each variant and its option. The option can be either a\nstring or an atom.","ref":"Turboprop.Variants.html#module-options"},{"type":"function","title":"Turboprop.Variants.variant/2","doc":"","ref":"Turboprop.Variants.html#variant/2"},{"type":"extras","title":"Changelog","doc":"# Changelog","ref":"changelog.html"},{"type":"extras","title":"Unreleased - Changelog","doc":"","ref":"changelog.html#unreleased"},{"type":"extras","title":"0.2.1 -- 2024-06-14 - Changelog","doc":"","ref":"changelog.html#0-2-1-2024-06-14"},{"type":"extras","title":"Fixed - Changelog","doc":"- Do not raise when a non-existent variant option is passed as string.\n- Apply class overrides last","ref":"changelog.html#fixed"},{"type":"extras","title":"0.2.0 - 2024-06-12 - Changelog","doc":"","ref":"changelog.html#0-2-0-2024-06-12"},{"type":"extras","title":"Added - Changelog","doc":"- New hook: `Turboprop.Hooks.Dialog`\n- New tool: `Turboprop.Variants`","ref":"changelog.html#added"},{"type":"extras","title":"Changed - Changelog","doc":"- Updated Zag","ref":"changelog.html#changed"},{"type":"extras","title":"0.1.4 - 2024-06-11 - Changelog","doc":"","ref":"changelog.html#0-1-4-2024-06-11"},{"type":"extras","title":"Added - Changelog","doc":"- New hook: `Turboprop.Hooks.PinInput`","ref":"changelog.html#added"},{"type":"extras","title":"0.1.3 - 2024-06-10 - Changelog","doc":"Initial release.","ref":"changelog.html#0-1-3-2024-06-10"}],"content_type":"text/markdown","producer":{"name":"ex_doc","version":[48,46,51,52,46,48]}}